@@ -3,7 +3,7 @@ package WebService::MinFraud::Error::Generic;
 use Moo;
 use namespace::autoclean;
 
-our $VERSION = '1.006000';
+our $VERSION = '1.007000';
 
 extends 'Throwable::Error';
 
@@ -23,7 +23,7 @@ WebService::MinFraud::Error::Generic - A generic exception class for WebService:
 
 =head1 VERSION
 
-version 1.006000
+version 1.007000
 
 =head1 SYNOPSIS
 
@@ -35,7 +35,7 @@ version 1.006000
   use Try::Tiny;
 
   my $client = WebService::MinFraud::Client->new(
-      user_id     => 42,
+      account_id  => 42,
       license_key => 'abcdef123456',
   );
 
