@@ -3,7 +3,7 @@ package WebService::MinFraud::Error::HTTP;
 use Moo;
 use namespace::autoclean;
 
-our $VERSION = '1.006000';
+our $VERSION = '1.007000';
 
 with 'WebService::MinFraud::Role::Error::HTTP';
 
@@ -25,7 +25,7 @@ WebService::MinFraud::Error::HTTP - An HTTP transport error
 
 =head1 VERSION
 
-version 1.006000
+version 1.007000
 
 =head1 SYNOPSIS
 
@@ -37,7 +37,7 @@ version 1.006000
   use Try::Tiny;
 
   my $client = WebService::MinFraud::Client->new(
-      user_id     => 42,
+      account_id  => 42,
       license_key => 'abcdef123456',
   );
 
