@@ -3,7 +3,7 @@ package WebService::MinFraud::Error::WebService;
 use Moo;
 use namespace::autoclean;
 
-our $VERSION = '1.006000';
+our $VERSION = '1.007000';
 
 use WebService::MinFraud::Types qw( Str );
 
@@ -33,7 +33,7 @@ WebService::MinFraud::Error::WebService - An explicit error returned by the minF
 
 =head1 VERSION
 
-version 1.006000
+version 1.007000
 
 =head1 SYNOPSIS
 
@@ -45,7 +45,7 @@ version 1.006000
   use Try::Tiny;
 
   my $client = WebService::MinFraud::Client->new(
-      user_id     => 42,
+      account_id  => 42,
       license_key => 'abcdef123456',
   );
 
