@@ -3,7 +3,7 @@ package WebService::MinFraud::Record::Disposition;
 use Moo;
 use namespace::autoclean;
 
-our $VERSION = '1.006000';
+our $VERSION = '1.007000';
 
 use Types::UUID;
 use WebService::MinFraud::Types qw( Str );
@@ -36,7 +36,7 @@ WebService::MinFraud::Record::Disposition - The disposition for the request as s
 
 =head1 VERSION
 
-version 1.006000
+version 1.007000
 
 =head1 SYNOPSIS
 
@@ -45,7 +45,7 @@ version 1.006000
   use WebService::MinFraud::Client;
 
   my $client = WebService::MinFraud::Client->new(
-      user_id     => 42,
+      account_id  => 42,
       license_key => 'abcdef123456',
   );
   my $request  = { device => { ip_address => '24.24.24.24' } };
