@@ -3,7 +3,7 @@ package WebService::MinFraud::Record::IPAddress;
 use Moo;
 use namespace::autoclean;
 
-our $VERSION = '1.006000';
+our $VERSION = '1.007000';
 
 use B;
 use GeoIP2::Role::Model::Location 2.004000;
@@ -70,7 +70,7 @@ WebService::MinFraud::Record::IPAddress - Contains data for the IPAddress record
 
 =head1 VERSION
 
-version 1.006000
+version 1.007000
 
 =head1 SYNOPSIS
 
@@ -79,7 +79,7 @@ version 1.006000
   use WebService::MinFraud::Client;
 
   my $client = WebService::MinFraud::Client->new(
-      user_id     => 42,
+      account_id  => 42,
       license_key => 'abcdef123456',
   );
   my $request    = { device => { ip_address => '24.24.24.24' } };
